@@ -39,6 +39,7 @@ class PartectorBluePrint(Thread, PartectorDefaults, ABC):
         self._port: Optional[str] = ""
         self._ser: serial.Serial = serial.Serial()
         self._time_last_message_received = time.time()
+        self._legacy_data_structure: bool = False
 
     def close(
         self, blocking: bool = False, shutdown: bool = False, verbose_reset: bool = True
@@ -124,6 +125,10 @@ class PartectorBluePrint(Thread, PartectorDefaults, ABC):
         self.custom_info_str = line
         self.custom_info_size = number_of_elem + 1
 
+        if number_of_elem == 0:
+            self._write_line(line)
+            return []
+
         return self._serial_wrapper(self._custom_info)  # type: ignore
 
     #########################################
@@ -211,10 +216,14 @@ class PartectorBluePrint(Thread, PartectorDefaults, ABC):
         unix_timestamp = int(datetime.now(tz=timezone.utc).timestamp() * 1000)
         data = [unix_timestamp] + line.split("\t")
 
-        self._notify_message_received()
+        # print(f"Received line length: {len(data)}, soll length: {len(self._data_structure)}")
 
+        self._notify_message_received()
         if len(data) == len(self._data_structure):
             self._queue.append(data)
+        # this is legacy mode, where the data structure is not known exactly
+        elif len(data) > len(self._data_structure) and self._legacy_data_structure:
+            self._queue.append(data[0 : len(self._data_structure)])
         else:
             self._queue_info.append(data)
 
